@@ -6,11 +6,11 @@ use rex_app::conn::DbConn;
 use rex_app::views::FullSummary;
 use thousands::Separable;
 
-use crate::page_handler::{
-    BACKGROUND, BOX, HEADER, IndexedData, SELECTED, SortingType, SummaryTab, TEXT, TableData,
-};
+use crate::page_handler::{IndexedData, SortingType, SummaryTab, TableData};
+use crate::theme::Theme;
 use crate::utility::{
     LerpState, create_tab, main_block, styled_block, styled_block_no_bottom, styled_block_no_top,
+    tab_highlight_style,
 };
 
 /// The function draws the Summary page of the interface.
@@ -25,7 +25,8 @@ pub fn summary_ui(
     summary_sort: &SortingType,
     lerp_state: &mut LerpState,
     full_summary: &FullSummary,
-    migrated_conn: &mut DbConn,
+    theme: &Theme,
+    conn: &mut DbConn,
 ) {
     let size = f.area();
 
@@ -47,7 +48,7 @@ pub fn summary_ui(
         "Total Expense"
     };
 
-    let mut table_headers = vec![
+    let mut tag_table_headers = vec![
         tag_header,
         total_income_header,
         total_expense_header,
@@ -55,17 +56,24 @@ pub fn summary_ui(
         "Expense %",
     ];
 
+    let mut lend_borrow_headers = vec!["Borrow", "Lend"];
+
     if mode_selection.index == 0 {
-        table_headers.push("MoM Income %");
-        table_headers.push("MoM Expense %");
+        tag_table_headers.push("MoM Income %");
+        tag_table_headers.push("MoM Expense %");
+
+        lend_borrow_headers.push("MoM Borrow %");
+        lend_borrow_headers.push("MoM Lend %");
     } else if mode_selection.index == 1 {
-        table_headers.push("YoY Income %");
-        table_headers.push("YoY Expense %");
+        tag_table_headers.push("YoY Income %");
+        tag_table_headers.push("YoY Expense %");
+
+        lend_borrow_headers.push("YoY Borrow %");
+        lend_borrow_headers.push("YoY Lend %");
     }
 
-    let header_cells = table_headers
-        .into_iter()
-        .map(|h| Cell::from(h).style(Style::default().fg(BACKGROUND)));
+    tag_table_headers.push("Borrow");
+    tag_table_headers.push("Lend");
 
     let mut method_headers = vec!["Method", "Total Income", "Total Expense"];
 
@@ -87,19 +95,32 @@ pub fn summary_ui(
 
     let method_header_cells = method_headers
         .iter()
-        .map(|h| Cell::from(*h).style(Style::default().fg(BACKGROUND)));
+        .map(|h| Cell::from(*h).style(Style::default().fg(theme.background())));
 
-    let header = Row::new(header_cells)
-        .style(Style::default().bg(HEADER))
+    let tag_table_header_cells = tag_table_headers
+        .into_iter()
+        .map(|h| Cell::from(h).style(Style::default().fg(theme.background())));
+
+    let lend_borrow_header_cells = lend_borrow_headers
+        .into_iter()
+        .map(|h| Cell::from(h).style(Style::default().fg(theme.background())));
+
+    let tag_table_header = Row::new(tag_table_header_cells)
+        .style(Style::default().bg(theme.header()))
         .height(1)
         .bottom_margin(0);
 
     let method_header = Row::new(method_header_cells)
-        .style(Style::default().bg(HEADER))
+        .style(Style::default().bg(theme.header()))
         .height(1)
         .bottom_margin(0);
 
-    let method_len = migrated_conn.get_tx_methods().len() as u16;
+    let lend_borrow_header = Row::new(lend_borrow_header_cells)
+        .style(Style::default().bg(theme.header()))
+        .height(1)
+        .bottom_margin(0);
+
+    let method_len = conn.get_tx_methods().len() as u16;
 
     let mut main_layout = Layout::default().direction(Direction::Vertical).margin(2);
     let mut summary_layout = Layout::default().direction(Direction::Horizontal);
@@ -109,6 +130,7 @@ pub fn summary_ui(
             Constraint::Length(method_len + 2),
             Constraint::Length(3),
             Constraint::Length(4),
+            Constraint::Length(4),
             Constraint::Min(0),
         ]);
         summary_layout =
@@ -123,6 +145,7 @@ pub fn summary_ui(
                     Constraint::Length(method_len + 2),
                     Constraint::Length(3),
                     Constraint::Length(4),
+                    Constraint::Length(4),
                     Constraint::Min(0),
                 ]);
                 summary_layout = summary_layout
@@ -135,6 +158,7 @@ pub fn summary_ui(
                     Constraint::Length(method_len + 2),
                     Constraint::Length(3),
                     Constraint::Length(4),
+                    Constraint::Length(4),
                     Constraint::Min(0),
                 ]);
                 summary_layout = summary_layout
@@ -146,29 +170,33 @@ pub fn summary_ui(
                     Constraint::Length(method_len + 2),
                     Constraint::Length(3),
                     Constraint::Length(4),
+                    Constraint::Length(4),
                     Constraint::Min(0),
                 ]);
                 summary_layout = summary_layout
-                    .constraints([Constraint::Percentage(100), Constraint::Percentage(50)]);
+                    .constraints([Constraint::Percentage(50), Constraint::Percentage(50)]);
             }
             _ => {}
         }
     }
 
     let chunks = main_layout.split(size);
+
+    // Horizontal split for the peak + largest area. Split the main block into several vertical
+    // chunk => Take a specific vertical take and split it into two Horizontal chunk once again
     let summary_chunk = if summary_hidden_mode {
-        summary_layout.split(chunks[2])
+        summary_layout.split(chunks[3])
     } else {
-        summary_layout.split(chunks[5 - mode_selection.index])
+        summary_layout.split(chunks[6 - mode_selection.index])
     };
 
-    f.render_widget(main_block(), size);
+    f.render_widget(main_block(theme), size);
 
-    let mut month_tab = create_tab(months, "Months");
+    let mut month_tab = create_tab(months, "Months", theme);
 
-    let mut year_tab = create_tab(years, "Years");
+    let mut year_tab = create_tab(years, "Years", theme);
 
-    let mut mode_selection_tab = create_tab(mode_selection, "Modes");
+    let mut mode_selection_tab = create_tab(mode_selection, "Modes", theme);
 
     // Goes through all tags provided and creates row for the table
     let rows = table_data
@@ -177,10 +205,16 @@ pub fn summary_ui(
         .enumerate()
         .map(|(row_index, item)| {
             let cells = item.iter().enumerate().map(|(index, c)| {
+                if index == 0 {
+                    return Cell::from(c.clone());
+                }
+
+                let lerp_id = format!("summary_table_main:{index}:{row_index}");
+
                 let Ok(parsed_num) = c.parse::<f64>() else {
                     if c == "∞" {
-                        let lerp_id = format!("summary_table_main:{index}:{row_index}");
-                        lerp_state.lerp(&lerp_id, 0.0);
+                        let new_c = lerp_state.lerp(&lerp_id, 0.0);
+                        return Cell::from(format!("{new_c:.2}").separate_with_commas());
                     }
 
                     let symbol = if c.contains('↑') || c.contains('↓') {
@@ -192,7 +226,6 @@ pub fn summary_ui(
                     if let Some(sym) = symbol {
                         let c = c.replace(sym, "");
                         if let Ok(parsed_num) = c.parse::<f64>() {
-                            let lerp_id = format!("summary_table_main:{index}:{row_index}");
                             let new_c = lerp_state.lerp(&lerp_id, parsed_num);
 
                             return Cell::from(format!("{sym}{new_c:.2}").separate_with_commas());
@@ -201,7 +234,6 @@ pub fn summary_ui(
                     return Cell::from(c.separate_with_commas());
                 };
 
-                let lerp_id = format!("summary_table_main:{index}:{row_index}");
                 let new_c = lerp_state.lerp(&lerp_id, parsed_num);
 
                 Cell::from(format!("{new_c:.2}").separate_with_commas())
@@ -209,33 +241,37 @@ pub fn summary_ui(
             Row::new(cells)
                 .height(1)
                 .bottom_margin(0)
-                .style(Style::default().fg(TEXT))
+                .style(Style::default().fg(theme.text()))
         });
 
     let table_width = if mode_selection.index == 2 {
         vec![
-            Constraint::Percentage(20),
-            Constraint::Percentage(20),
-            Constraint::Percentage(20),
-            Constraint::Percentage(20),
-            Constraint::Percentage(20),
+            Constraint::Percentage(15),
+            Constraint::Percentage(15),
+            Constraint::Percentage(14),
+            Constraint::Percentage(14),
+            Constraint::Percentage(14),
+            Constraint::Percentage(14),
+            Constraint::Percentage(14),
         ]
     } else {
         vec![
-            Constraint::Percentage(14),
-            Constraint::Percentage(14),
-            Constraint::Percentage(14),
-            Constraint::Percentage(14),
-            Constraint::Percentage(14),
-            Constraint::Percentage(14),
-            Constraint::Percentage(15),
+            Constraint::Percentage(12),
+            Constraint::Percentage(11),
+            Constraint::Percentage(11),
+            Constraint::Percentage(11),
+            Constraint::Percentage(11),
+            Constraint::Percentage(11),
+            Constraint::Percentage(11),
+            Constraint::Percentage(11),
+            Constraint::Percentage(11),
         ]
     };
 
     let mut table_area = Table::new(rows, table_width)
-        .header(header)
-        .block(styled_block("Tags"))
-        .style(Style::default().fg(BOX));
+        .header(tag_table_header)
+        .block(styled_block("Tags", theme))
+        .style(Style::default().fg(theme.border()));
 
     let summary_rows_largest =
         full_summary
@@ -254,14 +290,18 @@ pub fn summary_ui(
                     };
 
                     if index == 0 {
-                        cell = cell.style(Style::default().fg(TEXT).add_modifier(Modifier::BOLD));
+                        cell = cell.style(
+                            Style::default()
+                                .fg(theme.text())
+                                .add_modifier(Modifier::BOLD),
+                        );
                     }
                     cell
                 });
                 Row::new(cells)
                     .height(1)
                     .bottom_margin(0)
-                    .style(Style::default().fg(TEXT))
+                    .style(Style::default().fg(theme.text()))
             });
 
     let summary_area_largest = Table::new(
@@ -273,8 +313,8 @@ pub fn summary_ui(
             Constraint::Percentage(25),
         ],
     )
-    .block(styled_block(""))
-    .style(Style::default().fg(BOX));
+    .block(styled_block("", theme))
+    .style(Style::default().fg(theme.border()));
 
     let summary_rows_peak =
         full_summary
@@ -302,14 +342,18 @@ pub fn summary_ui(
                     };
 
                     if index == 0 {
-                        cell = cell.style(Style::default().fg(TEXT).add_modifier(Modifier::BOLD));
+                        cell = cell.style(
+                            Style::default()
+                                .fg(theme.text())
+                                .add_modifier(Modifier::BOLD),
+                        );
                     }
                     cell
                 });
                 Row::new(cells)
                     .height(height)
                     .bottom_margin(0)
-                    .style(Style::default().fg(TEXT))
+                    .style(Style::default().fg(theme.text()))
             });
 
     let summary_area_peak = Table::new(
@@ -320,8 +364,8 @@ pub fn summary_ui(
             Constraint::Percentage(33),
         ],
     )
-    .block(styled_block(""))
-    .style(Style::default().fg(BOX));
+    .block(styled_block("", theme))
+    .style(Style::default().fg(theme.border()));
 
     let method_rows =
         full_summary
@@ -362,14 +406,18 @@ pub fn summary_ui(
                     };
 
                     if index == 0 {
-                        cell = cell.style(Style::default().fg(TEXT).add_modifier(Modifier::BOLD));
+                        cell = cell.style(
+                            Style::default()
+                                .fg(theme.text())
+                                .add_modifier(Modifier::BOLD),
+                        );
                     }
                     cell
                 });
                 Row::new(cells)
                     .height(1)
                     .bottom_margin(0)
-                    .style(Style::default().fg(TEXT))
+                    .style(Style::default().fg(theme.text()))
             });
 
     let method_widths = if mode_selection.index == 2 {
@@ -408,8 +456,64 @@ pub fn summary_ui(
 
     let method_area = Table::new(method_rows, &method_widths)
         .header(method_header)
-        .block(styled_block_no_bottom(""))
-        .style(Style::default().fg(BOX));
+        .block(styled_block_no_bottom("", theme))
+        .style(Style::default().fg(theme.border()));
+
+    let lend_borrow_rows = full_summary
+        .lend_borrows_array()
+        .into_iter()
+        .enumerate()
+        .map(|(row_index, item)| {
+            let cells = item.into_iter().enumerate().map(|(index, c)| {
+                let lerp_id = format!("lend_borrow_table:{index}:{row_index}");
+
+                if let Ok(parsed_num) = c.parse::<f64>() {
+                    let new_c = lerp_state.lerp(&lerp_id, parsed_num);
+
+                    Cell::from(format!("{new_c:.2}").separate_with_commas())
+                } else {
+                    let symbol = if c.contains('↑') || c.contains('↓') {
+                        c.chars().next()
+                    } else {
+                        None
+                    };
+
+                    if let Some(sym) = symbol {
+                        let c = c.replace(sym, "");
+                        if let Ok(parsed_num) = c.parse::<f64>() {
+                            let new_c = lerp_state.lerp(&lerp_id, parsed_num);
+
+                            return Cell::from(format!("{sym}{new_c:.2}").separate_with_commas());
+                        }
+                    }
+
+                    if c == "∞" {
+                        lerp_state.lerp(&lerp_id, 0.0);
+                    }
+                    Cell::from(c.separate_with_commas())
+                }
+            });
+            Row::new(cells)
+                .height(1)
+                .bottom_margin(0)
+                .style(Style::default().fg(theme.text()))
+        });
+
+    let lend_borrow_widths = if mode_selection.index == 2 {
+        vec![Constraint::Percentage(50), Constraint::Percentage(50)]
+    } else {
+        vec![
+            Constraint::Percentage(25),
+            Constraint::Percentage(25),
+            Constraint::Percentage(25),
+            Constraint::Percentage(25),
+        ]
+    };
+
+    let lend_borrow_area = Table::new(lend_borrow_rows, &lend_borrow_widths)
+        .header(lend_borrow_header)
+        .block(styled_block("", theme))
+        .style(Style::default().fg(theme.border()));
 
     let net_row = full_summary
         .net_array()
@@ -437,7 +541,7 @@ pub fn summary_ui(
                     if let Some(sym) = symbol {
                         let c = c.replace(sym, "");
                         if let Ok(parsed_num) = c.parse::<f64>() {
-                            let lerp_id = format!("summary_table_main:{index}:{row_index}");
+                            let lerp_id = format!("summary_net_rows:{index}:{row_index}");
                             let new_c = lerp_state.lerp(&lerp_id, parsed_num);
 
                             return Cell::from(format!("{sym}{new_c:.2}").separate_with_commas());
@@ -447,39 +551,45 @@ pub fn summary_ui(
                 };
 
                 if index == 0 {
-                    cell = cell.style(Style::default().fg(TEXT).add_modifier(Modifier::BOLD));
+                    cell = cell.style(
+                        Style::default()
+                            .fg(theme.text())
+                            .add_modifier(Modifier::BOLD),
+                    );
                 }
                 cell
             });
             Row::new(cells)
                 .height(1)
                 .bottom_margin(0)
-                .style(Style::default().fg(TEXT))
+                .style(Style::default().fg(theme.text()))
         });
 
     let net_area = Table::new(net_row, &method_widths)
-        .block(styled_block_no_top(""))
-        .style(Style::default().fg(BOX));
+        .block(styled_block_no_top("", theme))
+        .style(Style::default().fg(theme.border()));
 
     match current_page {
         // Previously added a black block to year and month widget if a value is not selected
         // Now we will turn that black block into green if a value is selected
-        SummaryTab::Months => {
-            month_tab = month_tab
-                .highlight_style(Style::default().add_modifier(Modifier::BOLD).bg(SELECTED));
-        }
-
-        SummaryTab::Years => {
-            year_tab = year_tab
-                .highlight_style(Style::default().add_modifier(Modifier::BOLD).bg(SELECTED));
-        }
+        SummaryTab::Months => month_tab = month_tab.highlight_style(tab_highlight_style(theme)),
+        SummaryTab::Years => year_tab = year_tab.highlight_style(tab_highlight_style(theme)),
         SummaryTab::ModeSelection => {
-            mode_selection_tab = mode_selection_tab
-                .highlight_style(Style::default().add_modifier(Modifier::BOLD).bg(SELECTED));
+            mode_selection_tab = mode_selection_tab.highlight_style(tab_highlight_style(theme));
         }
         SummaryTab::Table => {
+            let add_modifier = theme.add_reverse_modifier();
+
+            let mut style = Style::default();
+
+            if add_modifier {
+                style = style.fg(theme.selected()).add_modifier(Modifier::REVERSED);
+            } else {
+                style = style.bg(theme.selected());
+            }
+
             table_area = table_area
-                .row_highlight_style(Style::default().bg(SELECTED))
+                .row_highlight_style(style)
                 .highlight_symbol(">> ");
         }
     }
@@ -495,7 +605,8 @@ pub fn summary_ui(
     f.render_widget(summary_area_peak, summary_chunk[0]);
 
     if summary_hidden_mode {
-        f.render_widget(table_area, chunks[3]);
+        f.render_stateful_widget(table_area, chunks[4], &mut table_data.state);
+        f.render_widget(lend_borrow_area, chunks[2]);
         f.render_widget(net_area, chunks[1]);
         f.render_widget(method_area, chunks[0]);
     } else {
@@ -505,19 +616,22 @@ pub fn summary_ui(
             0 => {
                 f.render_widget(year_tab, chunks[1]);
                 f.render_widget(month_tab, chunks[2]);
-                f.render_stateful_widget(table_area, chunks[6], &mut table_data.state);
+                f.render_stateful_widget(table_area, chunks[7], &mut table_data.state);
                 f.render_widget(net_area, chunks[4]);
+                f.render_widget(lend_borrow_area, chunks[5]);
                 f.render_widget(method_area, chunks[3]);
             }
             1 => {
                 f.render_widget(year_tab, chunks[1]);
-                f.render_stateful_widget(table_area, chunks[5], &mut table_data.state);
+                f.render_stateful_widget(table_area, chunks[6], &mut table_data.state);
                 f.render_widget(net_area, chunks[3]);
+                f.render_widget(lend_borrow_area, chunks[4]);
                 f.render_widget(method_area, chunks[2]);
             }
             2 => {
-                f.render_stateful_widget(table_area, chunks[4], &mut table_data.state);
+                f.render_stateful_widget(table_area, chunks[5], &mut table_data.state);
                 f.render_widget(net_area, chunks[2]);
+                f.render_widget(lend_borrow_area, chunks[3]);
                 f.render_widget(method_area, chunks[1]);
             }
             _ => {}
